pub fn configure_project(
project: &Path,
trail_data: &TrailDataConfig,
) -> Result<()>Expand description
Persist the canonical live area without disturbing other project law.
pub fn configure_project(
project: &Path,
trail_data: &TrailDataConfig,
) -> Result<()>Persist the canonical live area without disturbing other project law.